joker
    * ``auth_token`` Specify the api key to connect to the joker.com api


.. note::
   
   The Joker.com provider requires a valid token for authentication.
   You can create one in the section 'Manage Joker.com API access keys' of 'My Profile' in your Joker.com account.
   

